from __future__ import unicode_literals

from django.http import Http404
from django.utils.functional import SimpleLazyObject
from . import app_settings


def wagtailmenus(request):

    def _get_value_dict():
        current_page = request.META.get('WAGTAILMENUS_CURRENT_PAGE')
        section_root = request.META.get('WAGTAILMENUS_CURRENT_SECTION_ROOT')
        ancestor_ids = request.META.get(
            'WAGTAILMENUS_CURRENT_PAGE_ANCESTOR_IDS')
        match = None
        site = request.site

        guess_pos = app_settings.GUESS_TREE_POSITION_FROM_PATH
        sroot_depth = app_settings.SECTION_ROOT_DEPTH

        if guess_pos and not current_page:
            path_components = [pc for pc in request.path.split('/') if pc]
            # Keep trying to find a page using the path components until there
            # are no components left, or a page has been identified
            first_run = True
            while path_components and match is None:
                try:
                    match, args, kwargs = site.root_page.specific.route(
                        request, path_components)
                    ancestor_ids = match.get_ancestors(inclusive=True).filter(
                        depth__gte=sroot_depth).values_list('id', flat=True)
                    if first_run:
                        # A page was found matching the exact path, so it's
                        # safe to assume it's the 'current page'
                        current_page = match
                except Http404:
                    # No match found, so remove a path component and try again
                    path_components.pop()
                first_run = False

        if guess_pos and not section_root:
            best_match = current_page or match
            if best_match:
                if best_match.depth == sroot_depth:
                    section_root = best_match
                elif best_match.depth > sroot_depth:
                    # Attempt to identify the section root page from best_match
                    section_root = best_match.get_ancestors().filter(
                        depth__exact=sroot_depth).first()

        return {
            'current_page': current_page,
            'section_root': section_root,
            'current_page_ancestor_ids': ancestor_ids or (),
        }

    return {
        'wagtailmenus_vals': SimpleLazyObject(_get_value_dict),
        'USE_SPECIFIC_OFF': app_settings.USE_SPECIFIC_OFF,
        'USE_SPECIFIC_AUTO': app_settings.USE_SPECIFIC_AUTO,
        'USE_SPECIFIC_TOP_LEVEL': app_settings.USE_SPECIFIC_TOP_LEVEL,
        'USE_SPECIFIC_ALWAYS': app_settings.USE_SPECIFIC_ALWAYS,
    }



from .pages import (
    HomePage, TopLevelPage, LowLevelPage, TypicalPage, ContactPage
)
from .menus import (
    MainMenuCustomMenuItem, FlatMenuCustomMenuItem,
    CustomMainMenu, CustomFlatMenu,
    CustomMainMenuItem, CustomFlatMenuItem
)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.10 on 2016-09-30 05:45
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailmenus', '0015_auto_20160423_1348'),
    ]

    operations = [
        migrations.AddField(
            model_name='flatmenuitem',
            name='handle',
            field=models.CharField(verbose_name="handle", blank=True, help_text='Use this field to optionally specify an additional value for each menu item, which you can then reference in custom menu templates.', max_length=100),
        ),
        migrations.AddField(
            model_name='mainmenuitem',
            name='handle',
            field=models.CharField(verbose_name="handle", blank=True, help_text='Use this field to optionally specify an additional value for each menu item, which you can then reference in custom menu templates.', max_length=100),
        ),
    ]



from __future__ import unicode_literals
from wagtailmenus.utils.version import get_version, get_stable_branch_name

# major.minor.patch.release.number
# release must be one of alpha, beta, rc, or final
VERSION = (2, 2, 3, 'final', 0)
__version__ = get_version(VERSION)
stable_branch_name = get_stable_branch_name(VERSION)

default_app_config = 'wagtailmenus.apps.WagtailMenusConfig'


def get_main_menu_model_string():
    """
    Get the dotted ``app.Model`` name for the main menu model as a string.
    Useful for developers extending wagtailmenus, that need to refer to the
    main menu model (such as in foreign keys), but the model itself is not
    required.
    """
    from wagtailmenus import app_settings
    return app_settings.MAIN_MENU_MODEL


def get_flat_menu_model_string():
    """
    Get the dotted ``app.Model`` name for the flat menu model as a string.
    Useful for developers extending wagtailmenus, that need to refer to the
    flat menu model (such as in foreign keys), but the model itself is not
    required.
    """
    from wagtailmenus import app_settings
    return app_settings.FLAT_MENU_MODEL


def get_main_menu_model():
    """
    Get the model from the ``WAGTAILMENUS_MAIN_MENU_MODEL`` setting.
    Useful for developers extending wagtailmenus, and need the actual model.
    Defaults to the standard :class:`~wagtailmenus.models.MainMenu` model
    if no custom model is defined.
    """
    from wagtailmenus import app_settings
    return app_settings.MAIN_MENU_MODEL_CLASS


def get_flat_menu_model():
    """
    Get the model from the ``WAGTAILMENUS_FLAT_MENU_MODEL`` setting.
    Useful for developers extending wagtailmenus, and need to the actual model.
    Defaults to the standard :class:`~wagtailmenus.models.FlatMenu` model
    if no custom model is defined.
    """
    from wagtailmenus import app_settings
    return app_settings.FLAT_MENU_MODEL_CLASS



from __future__ import absolute_import, unicode_literals

from copy import copy

from django.db import models
from django.utils.translation import ugettext_lazy as _

from wagtail.wagtailcore.models import Page

from .. import app_settings
from ..panels import menupage_settings_panels


class MenuPage(Page):
    repeat_in_subnav = models.BooleanField(
        verbose_name=_("repeat in sub-navigation"),
        default=False,
        help_text=_(
            "If checked, a link to this page will be repeated alongside it's "
            "direct children when displaying a sub-navigation for this page."
        ),
    )
    repeated_item_text = models.CharField(
        verbose_name=_('repeated item link text'),
        max_length=255,
        blank=True,
        help_text=_(
            "e.g. 'Section home' or 'Overview'. If left blank, the page title "
            "will be used."
        )
    )

    settings_panels = menupage_settings_panels

    class Meta:
        abstract = True

    def modify_submenu_items(
        self, menu_items, current_page, current_ancestor_ids, current_site,
        allow_repeating_parents, apply_active_classes, original_menu_tag,
        menu_instance
    ):
        """
        Make any necessary modifications to `menu_items` and return the list
        back to the calling menu tag to render in templates. Any additional
        items added should have a `text` and `href` attribute as a minimum.

        `original_menu_tag` should be one of 'main_menu', 'section_menu' or
        'children_menu', which should be useful when extending/overriding.
        """
        if (allow_repeating_parents and menu_items and self.repeat_in_subnav):
            """
            This page should have a version of itself repeated alongside
            children in the subnav, so we create a new item and prepend it to
            menu_items.
            """
            menu_items.insert(0, self.get_repeated_menu_item(
                current_page, current_site, apply_active_classes,
                original_menu_tag
            ))
        return menu_items

    def has_submenu_items(
        self, current_page, allow_repeating_parents, original_menu_tag,
        menu_instance
    ):
        """
        When rendering pages in a menu template a `has_children_in_menu`
        attribute is added to each page, letting template developers know
        whether or not the item has a submenu that must be rendered.

        By default, we return a boolean indicating whether the page has
        suitable child pages to include in such a menu. But, if you are
        overriding the `modify_submenu_items` method to programatically add
        items that aren't child pages, you'll likely need to alter this method
        too, so the template knows there are sub items to be rendered.
        """
        return menu_instance.page_has_children(self)

    def get_repeated_menu_item(
        self, current_page, current_site, apply_active_classes,
        original_menu_tag
    ):
        """Return something that can be used to display a 'repeated' menu item
        for this specific page."""

        menuitem = copy(self)
        setattr(menuitem, 'text', self.repeated_item_text or self.title)
        setattr(menuitem, 'href', self.relative_url(current_site))
        active_class = ''
        if apply_active_classes and self == current_page:
            active_class = app_settings.ACTIVE_CLASS
        setattr(menuitem, 'active_class', active_class)
        setattr(menuitem, 'has_children_in_menu', False)
        return menuitem



# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-04-18 11:04
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0002_homepage'),
    ]

    operations = [
        migrations.AlterField(
            model_name='homepage',
            name='repeat_in_subnav',
            field=models.BooleanField(default=False, help_text="If checked, a link to this page will be repeated alongside it's direct children when displaying a sub-navigation for this page.", verbose_name='repeat in sub-navigation'),
        ),
        migrations.AlterField(
            model_name='homepage',
            name='subnav_menu_text',
            field=models.CharField(blank=True, help_text="e.g. 'Section home' or 'Overview'. If left blank, the page title will be used.", max_length=255, verbose_name='link text for sub-navigation item'),
        ),
        migrations.AlterField(
            model_name='toplevelpage',
            name='repeat_in_subnav',
            field=models.BooleanField(default=False, help_text="If checked, a link to this page will be repeated alongside it's direct children when displaying a sub-navigation for this page.", verbose_name='repeat in sub-navigation'),
        ),
        migrations.AlterField(
            model_name='toplevelpage',
            name='subnav_menu_text',
            field=models.CharField(blank=True, help_text="e.g. 'Section home' or 'Overview'. If left blank, the page title will be used.", max_length=255, verbose_name='link text for sub-navigation item'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-04-23 10:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailmenus', '0012_auto_20160419_0039'),
    ]

    operations = [
        migrations.AddField(
            model_name='flatmenuitem',
            name='allow_subnav',
            field=models.BooleanField(default=False, verbose_name='allow sub-navigation for this item'),
        ),
        migrations.AlterField(
            model_name='mainmenuitem',
            name='allow_subnav',
            field=models.BooleanField(default=True, verbose_name='allow sub-navigation for this item'),
        ),
    ]



from .pages import MenuPage
from .menus import (
    Menu, MenuFromRootPage, MenuWithMenuItems,
    AbstractMainMenu, AbstractFlatMenu,
    MainMenu, FlatMenu
)
from .menuitems import (
    MenuItem, AbstractMenuItem, AbstractMainMenuItem, AbstractFlatMenuItem,
    MainMenuItem, FlatMenuItem
)



from django.utils import translation


class TranslatedField(object):
    def __init__(self, en_field, de_field, fr_field):
        self.en_field = en_field
        self.de_field = de_field
        self.fr_field = fr_field

    def __get__(self, instance, owner):
        english = getattr(instance, self.en_field)
        trans_field_name = '%s_field' % translation.get_language()
        trans_field = getattr(self, trans_field_name, None)
        if trans_field:
            return getattr(instance, trans_field) or english
        return english



from wagtail.wagtailcore.models import Page, Site
from wagtailmenus.models.menuitems import MenuItem


def get_attrs_from_context(context, guess_tree_position=True):
    """
    Gets a bunch of useful things from the context/request and returns them as
    a tuple for use in most menu tags.
    """
    try:
        request = context['request']
    except KeyError:
        request = None

    site = get_site_from_request(request)
    wagtailmenus_vals = context.get('wagtailmenus_vals')
    current_page = wagtailmenus_vals.get('current_page')
    section_root = wagtailmenus_vals.get('section_root')
    ancestor_ids = wagtailmenus_vals.get('current_page_ancestor_ids')
    return (request, site, current_page, section_root, ancestor_ids)


def get_site_from_request(request, fallback_to_default=True):
    try:
        return request.site
    except AttributeError:
        if fallback_to_default:
            return Site.objects.filter(is_default_site=True).first()
    return None


def validate_supplied_values(tag, max_levels=None, use_specific=None,
                             parent_page=None, menuitem_or_page=None):
    if max_levels is not None:
        if max_levels not in (1, 2, 3, 4, 5):
            raise ValueError(
                "The `%s` tag expects `max_levels` to be an integer value "
                "between 1 and 5. Please review your template." % tag
            )
    if use_specific is not None:
        if use_specific not in (0, 1, 2, 3):
            raise ValueError(
                "The `%s` tag expects `use_specific` to be an integer value "
                "between 0 and 3. Please review your template." % tag
            )
    if parent_page is not None:
        if not isinstance(parent_page, Page):
            raise ValueError(
                "The `%s` tag expects `parent_page` to be a `Page` instance. "
                "A value of type `%s` was supplied." %
                (tag, parent_page.__class__)
            )
    if menuitem_or_page is not None:
        if not isinstance(menuitem_or_page, (Page, MenuItem)):
            raise ValueError(
                "The `%s` tag expects `menuitem_or_page` to be a `Page` or "
                "`MenuItem` instance. A value of type `%s` was supplied." %
                (tag, menuitem_or_page.__class__)
            )



from django.utils.translation import ugettext_lazy as _


class AppSettings(object):
    """Props to django-allauth for the inspiration"""

    USE_SPECIFIC_OFF = 0
    USE_SPECIFIC_AUTO = 1
    USE_SPECIFIC_TOP_LEVEL = 2
    USE_SPECIFIC_ALWAYS = 3
    USE_SPECIFIC_CHOICES = (
        (USE_SPECIFIC_OFF, _("Off (most efficient)")),
        (USE_SPECIFIC_AUTO, _("Auto")),
        (USE_SPECIFIC_TOP_LEVEL, _("Top level")),
        (USE_SPECIFIC_ALWAYS, _("Always (least efficient)")),
    )
    MAX_LEVELS_CHOICES = (
        (1, _('1: No sub-navigation (flat)')),
        (2, _('2: Allow 1 level of sub-navigation')),
        (3, _('3: Allow 2 levels of sub-navigation')),
        (4, _('4: Allow 3 levels of sub-navigation')),
    )

    def __init__(self, prefix):
        from django.conf import settings
        self._prefix = prefix
        self._settings = settings

    def _setting(self, name, default):
        return getattr(self._settings, self._prefix + name, default)

    def _model_class(self, model_name_setting_name):
        from django.apps import apps
        from django.core.exceptions import ImproperlyConfigured
        model_name = getattr(self, model_name_setting_name)
        try:
            return apps.get_model(model_name)
        except ValueError:
            raise ImproperlyConfigured(
                "%s%s must be of the form 'app_label.model_name'" %
                (self._prefix, model_name_setting_name)
            )
        except LookupError:
            raise ImproperlyConfigured(
                "%s%s refers to model '%s' that has not been installed" %
                (self._prefix, model_name_setting_name, model_name)
            )

    @property
    def ACTIVE_CLASS(self):
        return self._setting('ACTIVE_CLASS', 'active')

    @property
    def ADD_EDITOR_OVERRIDE_STYLES(self):
        return self._setting('ADD_EDITOR_OVERRIDE_STYLES', True)

    @property
    def ACTIVE_ANCESTOR_CLASS(self):
        return self._setting('ACTIVE_ANCESTOR_CLASS', 'ancestor')

    @property
    def MAINMENU_MENU_ICON(self):
        return self._setting('MAINMENU_MENU_ICON', 'list-ol')

    @property
    def FLATMENU_MENU_ICON(self):
        return self._setting('FLATMENU_MENU_ICON', 'list-ol')

    @property
    def SITE_SPECIFIC_TEMPLATE_DIRS(self):
        return self._setting('SITE_SPECIFIC_TEMPLATE_DIRS', False)

    @property
    def SECTION_ROOT_DEPTH(self):
        return self._setting('SECTION_ROOT_DEPTH', 3)

    @property
    def GUESS_TREE_POSITION_FROM_PATH(self):
        return self._setting('GUESS_TREE_POSITION_FROM_PATH', True)

    @property
    def FLAT_MENUS_FALL_BACK_TO_DEFAULT_SITE_MENUS(self):
        return self._setting(
            'FLAT_MENUS_FALL_BACK_TO_DEFAULT_SITE_MENUS', False
        )

    @property
    def DEFAULT_MAIN_MENU_TEMPLATE(self):
        return self._setting(
            'DEFAULT_MAIN_MENU_TEMPLATE', 'menus/main_menu.html'
        )

    @property
    def DEFAULT_FLAT_MENU_TEMPLATE(self):
        return self._setting(
            'DEFAULT_FLAT_MENU_TEMPLATE', 'menus/flat_menu.html'
        )

    @property
    def DEFAULT_SECTION_MENU_TEMPLATE(self):
        return self._setting(
            'DEFAULT_SECTION_MENU_TEMPLATE', 'menus/section_menu.html'
        )

    @property
    def DEFAULT_CHILDREN_MENU_TEMPLATE(self):
        return self._setting(
            'DEFAULT_CHILDREN_MENU_TEMPLATE', 'menus/children_menu.html'
        )

    @property
    def DEFAULT_SUB_MENU_TEMPLATE(self):
        return self._setting(
            'DEFAULT_SUB_MENU_TEMPLATE', 'menus/sub_menu.html'
        )

    @property
    def DEFAULT_SECTION_MENU_MAX_LEVELS(self):
        return self._setting('DEFAULT_SECTION_MENU_MAX_LEVELS', 2)

    @property
    def DEFAULT_CHILDREN_MENU_MAX_LEVELS(self):
        return self._setting('DEFAULT_CHILDREN_MENU_MAX_LEVELS', 1)

    @property
    def DEFAULT_SECTION_MENU_USE_SPECIFIC(self):
        return self._setting(
            'DEFAULT_SECTION_MENU_USE_SPECIFIC', self.USE_SPECIFIC_AUTO
        )

    @property
    def DEFAULT_CHILDREN_MENU_USE_SPECIFIC(self):
        return self._setting(
            'DEFAULT_CHILDREN_MENU_USE_SPECIFIC', self.USE_SPECIFIC_AUTO
        )

    @property
    def FLAT_MENUS_HANDLE_CHOICES(self):
        return self._setting('FLAT_MENUS_HANDLE_CHOICES', None)

    @property
    def PAGE_FIELD_FOR_MENU_ITEM_TEXT(self):
        return self._setting("PAGE_FIELD_FOR_MENU_ITEM_TEXT", 'title')

    @property
    def MAIN_MENU_MODEL(self):
        return self._setting('MAIN_MENU_MODEL', 'wagtailmenus.MainMenu')

    @property
    def MAIN_MENU_MODEL_CLASS(self):
        return self._model_class('MAIN_MENU_MODEL')

    @property
    def FLAT_MENU_MODEL(self):
        return self._setting('FLAT_MENU_MODEL', 'wagtailmenus.FlatMenu')

    @property
    def FLAT_MENU_MODEL_CLASS(self):
        return self._model_class('FLAT_MENU_MODEL')

    @property
    def MAIN_MENU_ITEMS_RELATED_NAME(self):
        return self._setting('MAIN_MENU_ITEMS_RELATED_NAME', 'menu_items')

    @property
    def FLAT_MENU_ITEMS_RELATED_NAME(self):
        return self._setting('FLAT_MENU_ITEMS_RELATED_NAME', 'menu_items')


import sys  # noqa

app_settings = AppSettings('WAGTAILMENUS_')
app_settings.__name__ = __name__
sys.modules[__name__] = app_settings



from __future__ import absolute_import, unicode_literals

from django import forms
from wagtail.wagtailadmin.forms import WagtailAdminModelForm

from . import app_settings


class FlatMenuAdminForm(WagtailAdminModelForm):
    def __init__(self, *args, **kwargs):
        super(FlatMenuAdminForm, self).__init__(*args, **kwargs)
        if app_settings.FLAT_MENUS_HANDLE_CHOICES:
            self.fields['handle'] = forms.ChoiceField(
                choices=app_settings.FLAT_MENUS_HANDLE_CHOICES)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailmenus', '0006_auto_20160131_1347'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='flatmenuitem',
            name='url_append',
        ),
        migrations.RemoveField(
            model_name='mainmenuitem',
            name='url_append',
        ),
        migrations.AlterField(
            model_name='flatmenuitem',
            name='link_page',
            field=models.ForeignKey(verbose_name='Link to an internal page', blank=True, to='wagtailcore.Page', null=True),
        ),
        migrations.AlterField(
            model_name='mainmenuitem',
            name='link_page',
            field=models.ForeignKey(verbose_name='Link to an internal page', blank=True, to='wagtailcore.Page', null=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailmenus', '0005_auto_20160130_2209'),
    ]

    operations = [
        migrations.AlterField(
            model_name='flatmenuitem',
            name='url_append',
            field=models.CharField(help_text="e.g. '#about-section', '#tab-contact' or '?abc=xyz'", max_length=255, verbose_name='hash or querystring to append to URL', blank=True),
        ),
        migrations.AlterField(
            model_name='mainmenuitem',
            name='children_menu_link_text',
            field=models.CharField(help_text="e.g. 'Section home' or 'Overview'. If left blank, the page title will be used.", max_length=255, verbose_name='Link text for sub-menu item', blank=True),
        ),
        migrations.AlterField(
            model_name='mainmenuitem',
            name='url_append',
            field=models.CharField(help_text="e.g. '#about-section', '#tab-contact' or '?abc=xyz'", max_length=255, verbose_name='hash or querystring to append to URL', blank=True),
        ),
    ]



import os
from django.conf.global_settings import *  # NOQA

DEBUG = True
SITE_ID = 1

TIME_ZONE = 'Europe/London'
USE_TZ = True
USE_I18N = True
USE_L10N = True
LANGUAGE_CODE = 'en'


INSTALLED_APPS = (
    'wagtail.contrib.settings',
    'wagtail.wagtailforms',
    'wagtail.wagtailsearch',
    'wagtail.wagtailembeds',
    'wagtail.wagtailimages',
    'wagtail.wagtailsites',
    'wagtail.wagtailusers',
    'wagtail.wagtailsnippets',
    'wagtail.wagtaildocs',
    'wagtail.wagtailredirects',
    'wagtail.wagtailadmin',
    'wagtail.wagtailcore',
    'wagtail.contrib.modeladmin',
    'wagtailmenus',

    'taggit',
    'modelcluster',

    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.sites'
)

PROJECT_ROOT = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
STATIC_ROOT = os.path.join(PROJECT_ROOT, 'staticfiles')
STATIC_URL = '/static/'
MEDIA_ROOT = os.path.join(PROJECT_ROOT, 'media')
MEDIA_URL = '/media/'

SECRET_KEY = 'fake-key'
LOGIN_URL = 'wagtailadmin_login'
LOGIN_REDIRECT_URL = 'wagtailadmin_home'

LOCALE_PATHS = (
    os.path.join(PROJECT_ROOT, 'locale'),
)

# =============================================================================
# Templates
# =============================================================================

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            os.path.join(PROJECT_ROOT, 'templates'),
        ],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.contrib.auth.context_processors.auth',
                'django.template.context_processors.debug',
                'django.template.context_processors.i18n',
                'django.template.context_processors.media',
                'django.template.context_processors.request',
                'django.template.context_processors.static',
                'django.template.context_processors.tz',
                'django.contrib.messages.context_processors.messages',
                'wagtail.contrib.settings.context_processors.settings',
                'wagtailmenus.context_processors.wagtailmenus'
            ],
        },
    },
]

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'wagtail.wagtailcore.middleware.SiteMiddleware',
    'wagtail.wagtailredirects.middleware.RedirectMiddleware',
)

STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    'compressor.finders.CompressorFinder',
)

WAGTAILMENUS_FLAT_MENUS_HANDLE_CHOICES = (
    ('contact', 'contact'),
    ('footer', 'footer'),
    ('header-secondary', 'header-secondary'),
)



from .misc import get_site_from_request
from wagtailmenus import app_settings


def get_template_names(menu_tag, request, override):
    if override:
        return [override]
    template_names = []
    site = get_site_from_request(request)
    if app_settings.SITE_SPECIFIC_TEMPLATE_DIRS and site:
        hostname = site.hostname
        template_names.extend([
            "menus/%s/%s/menu.html" % (hostname, menu_tag),
            "menus/%s/%s_menu.html" % (hostname, menu_tag),
        ])
    template_names.append("menus/%s/menu.html" % menu_tag)
    if menu_tag == 'main':
        template_names.append(app_settings.DEFAULT_MAIN_MENU_TEMPLATE)
    elif menu_tag == 'section':
        template_names.append(app_settings.DEFAULT_SECTION_MENU_TEMPLATE)
    elif menu_tag == 'children':
        template_names.append(app_settings.DEFAULT_CHILDREN_MENU_TEMPLATE)
    return template_names


def get_sub_menu_template_names(menu_tag, request, override):
    if override:
        return [override]
    template_names = []
    if app_settings.SITE_SPECIFIC_TEMPLATE_DIRS and getattr(
        request, 'site', None
    ):
        hostname = request.site.hostname
        template_names.extend([
            "menus/%s/%s/sub_menu.html" % (hostname, menu_tag),
            "menus/%s/%s_sub_menu.html" % (hostname, menu_tag),
            "menus/%s/sub_menu.html" % hostname,
        ])
    template_names.extend([
        "menus/%s/sub_menu.html" % menu_tag,
        "menus/%s_sub_menu.html" % menu_tag,
        app_settings.DEFAULT_SUB_MENU_TEMPLATE,
    ])
    return template_names



# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-12-11 21:16
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import modelcluster.fields
import wagtailmenus.models.menuitems
import wagtailmenus.models.menus


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailmenus', '0020_auto_20161210_0004'),
        ('tests', '0009_typicalpage'),
    ]

    operations = [
        migrations.CreateModel(
            name='CustomFlatMenu',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(help_text='For internal reference only.', max_length=255, verbose_name='title')),
                ('handle', models.SlugField(help_text='Used to reference this menu in templates etc. Must be unique for the selected site.', max_length=100, verbose_name='handle')),
                ('heading', models.CharField(blank=True, help_text='If supplied, appears above the menu when rendered.', max_length=255, verbose_name='heading')),
                ('max_levels', models.PositiveSmallIntegerField(choices=[(1, '1: No sub-navigation (flat)'), (2, '2: Allow 1 level of sub-navigation'), (3, '3: Allow 2 levels of sub-navigation'), (4, '4: Allow 3 levels of sub-navigation')], default=1, help_text='The maximum number of levels to display when rendering this menu. The value can be overidden by supplying a different <code>max_levels</code> value to the <code>{% flat_menu %}</code> tag in your templates.', verbose_name='maximum levels')),
                ('use_specific', models.PositiveSmallIntegerField(choices=[(0, 'Off (most efficient)'), (1, 'Auto'), (2, 'Top level'), (3, 'Always (least efficient)')], default=1, help_text="Controls how 'specific' pages objects are fetched and used when rendering this menu. This value can be overidden by supplying a different <code>use_specific</code> value to the <code>{% flat_menu %}</code> tag in your templates.", verbose_name='specific page usage')),
                ('heading_de', models.CharField(blank=True, max_length=255, verbose_name='heading (de)')),
                ('heading_fr', models.CharField(blank=True, max_length=255, verbose_name='heading (fr)')),
                ('site', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='wagtailcore.Site', verbose_name='site')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'flat menu',
                'verbose_name_plural': 'flat menus',
            },
            bases=(models.Model, wagtailmenus.models.menus.Menu),
        ),
        migrations.CreateModel(
            name='CustomFlatMenuItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('link_url', models.CharField(blank=True, max_length=255, null=True, verbose_name='link to a custom URL')),
                ('link_text', models.CharField(blank=True, help_text="Provide the text to use for a custom URL, or set on an internal page link to use instead of the page's title.", max_length=255, verbose_name='link text')),
                ('handle', models.CharField(blank=True, help_text='Use this field to optionally specify an additional value for each menu item, which you can then reference in custom menu templates.', max_length=100, verbose_name='handle')),
                ('url_append', models.CharField(blank=True, help_text="Use this to optionally append a #hash or querystring to the above page's URL.", max_length=255, verbose_name='append to URL')),
                ('allow_subnav', models.BooleanField(default=False, help_text="NOTE: The sub-menu might not be displayed, even if checked. It depends on how the menu is used in this project's templates.", verbose_name='allow sub-menu for this item')),
                ('link_text_de', models.CharField(blank=True, max_length=255, verbose_name='link text (de)')),
                ('link_text_fr', models.CharField(blank=True, max_length=255, verbose_name='link text (fr)')),
                ('link_page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Page', verbose_name='link to an internal page')),
                ('menu', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='menu_items', to='tests.CustomFlatMenu')),
            ],
            options={
                'abstract': False,
            },
            bases=(models.Model, wagtailmenus.models.menuitems.MenuItem),
        ),
        migrations.CreateModel(
            name='CustomMainMenu',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('max_levels', models.PositiveSmallIntegerField(choices=[(1, '1: No sub-navigation (flat)'), (2, '2: Allow 1 level of sub-navigation'), (3, '3: Allow 2 levels of sub-navigation'), (4, '4: Allow 3 levels of sub-navigation')], default=2, help_text='The maximum number of levels to display when rendering this menu. The value can be overidden by supplying a different <code>max_levels</code> value to the <code>{% main_menu %}</code> tag in your templates.', verbose_name='maximum levels')),
                ('use_specific', models.PositiveSmallIntegerField(choices=[(0, 'Off (most efficient)'), (1, 'Auto'), (2, 'Top level'), (3, 'Always (least efficient)')], default=1, help_text="Controls how 'specific' pages objects are fetched and used when rendering this menu. This value can be overidden by supplying a different <code>use_specific</code> value to the <code>{% main_menu %}</code> tag in your templates.", verbose_name='specific page usage')),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='wagtailcore.Site', verbose_name='site')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'main menu',
                'verbose_name_plural': 'main menu',
            },
            bases=(models.Model, wagtailmenus.models.menus.Menu),
        ),
        migrations.CreateModel(
            name='CustomMainMenuItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('link_url', models.CharField(blank=True, max_length=255, null=True, verbose_name='link to a custom URL')),
                ('link_text', models.CharField(blank=True, help_text="Provide the text to use for a custom URL, or set on an internal page link to use instead of the page's title.", max_length=255, verbose_name='link text')),
                ('handle', models.CharField(blank=True, help_text='Use this field to optionally specify an additional value for each menu item, which you can then reference in custom menu templates.', max_length=100, verbose_name='handle')),
                ('url_append', models.CharField(blank=True, help_text="Use this to optionally append a #hash or querystring to the above page's URL.", max_length=255, verbose_name='append to URL')),
                ('allow_subnav', models.BooleanField(default=True, help_text="NOTE: The sub-menu might not be displayed, even if checked. It depends on how the menu is used in this project's templates.", verbose_name='allow sub-menu for this item')),
                ('link_text_de', models.CharField(blank=True, max_length=255, verbose_name='link text (de)')),
                ('link_text_fr', models.CharField(blank=True, max_length=255, verbose_name='link text (fr)')),
                ('link_page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Page', verbose_name='link to an internal page')),
                ('menu', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='menu_items', to='tests.CustomMainMenu')),
            ],
            options={
                'abstract': False,
            },
            bases=(models.Model, wagtailmenus.models.menuitems.MenuItem),
        ),
        migrations.CreateModel(
            name='FlatMenuCustomMenuItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('link_url', models.CharField(blank=True, max_length=255, null=True, verbose_name='link to a custom URL')),
                ('link_text', models.CharField(blank=True, help_text="Provide the text to use for a custom URL, or set on an internal page link to use instead of the page's title.", max_length=255, verbose_name='link text')),
                ('handle', models.CharField(blank=True, help_text='Use this field to optionally specify an additional value for each menu item, which you can then reference in custom menu templates.', max_length=100, verbose_name='handle')),
                ('url_append', models.CharField(blank=True, help_text="Use this to optionally append a #hash or querystring to the above page's URL.", max_length=255, verbose_name='append to URL')),
                ('allow_subnav', models.BooleanField(default=False, help_text="NOTE: The sub-menu might not be displayed, even if checked. It depends on how the menu is used in this project's templates.", verbose_name='allow sub-menu for this item')),
                ('link_text_de', models.CharField(blank=True, max_length=255, verbose_name='link text (de)')),
                ('link_text_fr', models.CharField(blank=True, max_length=255, verbose_name='link text (fr)')),
                ('link_page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Page', verbose_name='link to an internal page')),
                ('menu', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='custom_menu_items', to='wagtailmenus.FlatMenu')),
            ],
            options={
                'abstract': False,
            },
            bases=(models.Model, wagtailmenus.models.menuitems.MenuItem),
        ),
        migrations.CreateModel(
            name='MainMenuCustomMenuItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sort_order', models.IntegerField(blank=True, editable=False, null=True)),
                ('link_url', models.CharField(blank=True, max_length=255, null=True, verbose_name='link to a custom URL')),
                ('link_text', models.CharField(blank=True, help_text="Provide the text to use for a custom URL, or set on an internal page link to use instead of the page's title.", max_length=255, verbose_name='link text')),
                ('handle', models.CharField(blank=True, help_text='Use this field to optionally specify an additional value for each menu item, which you can then reference in custom menu templates.', max_length=100, verbose_name='handle')),
                ('url_append', models.CharField(blank=True, help_text="Use this to optionally append a #hash or querystring to the above page's URL.", max_length=255, verbose_name='append to URL')),
                ('allow_subnav', models.BooleanField(default=True, help_text="NOTE: The sub-menu might not be displayed, even if checked. It depends on how the menu is used in this project's templates.", verbose_name='allow sub-menu for this item')),
                ('link_text_de', models.CharField(blank=True, max_length=255, verbose_name='link text (de)')),
                ('link_text_fr', models.CharField(blank=True, max_length=255, verbose_name='link text (fr)')),
                ('link_page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Page', verbose_name='link to an internal page')),
                ('menu', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='custom_menu_items', to='wagtailmenus.MainMenu')),
            ],
            options={
                'abstract': False,
            },
            bases=(models.Model, wagtailmenus.models.menuitems.MenuItem),
        ),
        migrations.AddField(
            model_name='toplevelpage',
            name='repeated_item_text_de',
            field=models.CharField(blank=True, max_length=255, verbose_name='repeated item link text (de)'),
        ),
        migrations.AddField(
            model_name='toplevelpage',
            name='repeated_item_text_fr',
            field=models.CharField(blank=True, max_length=255, verbose_name='repeated item link text (fr)'),
        ),
        migrations.AddField(
            model_name='toplevelpage',
            name='title_de',
            field=models.CharField(blank=True, max_length=255, verbose_name='title (de)'),
        ),
        migrations.AddField(
            model_name='toplevelpage',
            name='title_fr',
            field=models.CharField(blank=True, max_length=255, verbose_name='title (fr)'),
        ),
        migrations.AlterUniqueTogether(
            name='customflatmenu',
            unique_together=set([('site', 'handle')]),
        ),
    ]
